==> haskell-arch-web-0.2-108-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-arch-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 arch-web
version:              0.2
visibility:           public
id:                   arch-web-0.2-14CBI800eBJFEWdMkv6ryj
key:                  arch-web-0.2-14CBI800eBJFEWdMkv6ryj
license:              MIT
copyright:            Copyright (c) berberman 2021
maintainer:           berberman <berberman@yandex.com>
author:               berberman
stability:            alpha
homepage:             https://github.com/berberman/arch-web
synopsis:             Arch Linux official and AUR web interface binding
description:
    Arch Linux official and AUR web interface binding.
    See README for details.

category:             Web
abi:                  72607e2e8079826dd55636c3e29c5811
exposed:              True
exposed-modules:
    Web.ArchLinux Web.ArchLinux.API Web.ArchLinux.Types
    Web.ArchLinux.Types.Lens

hidden-modules:       Web.ArchLinux.Types.API
import-dirs:          /usr/lib/ghc-9.2.8/site-local/arch-web-0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/arch-web-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arch-web
hs-libraries:         HSarch-web-0.2-14CBI800eBJFEWdMkv6ryj
depends:
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV base-4.16.4.0
    deriving-aeson-0.2.9-5MqQsaXoT7k9uAjZbYGpMM exceptions-0.10.4
    http-client-0.7.15-DQnyZx9lzoSgMdf26TxD3
    http-client-tls-0.3.6.3-vm9lZXKKPQG6YiMQwXwb7
    http-types-0.12.4-B3znMwHTe3dL304Bd3IJgZ
    lens-5.2.3-Lr9JV2q3Rgv6Xn7f42cFjs mtl-2.2.2
    servant-0.20.1-GLej8ldIOOu81Qu62QAP65
    servant-client-0.20-ANeZTzgUxwH9gRYRpGDNay
    servant-client-core-0.20-HaYOWP3vx4FCl7MBpWbcbp text-1.2.5.0
    time-1.11.1.1

haddock-interfaces:   /usr/share/doc/haskell-arch-web/html/arch-web.haddock
haddock-html:         /usr/share/doc/haskell-arch-web/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-arch-web-0.2-138.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-arch-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 arch-web
version:              0.2
visibility:           public
id:                   arch-web-0.2-Up5GzlXDDZ6EO4r6prGGm
key:                  arch-web-0.2-Up5GzlXDDZ6EO4r6prGGm
license:              MIT
copyright:            Copyright (c) berberman 2021
maintainer:           berberman <berberman@yandex.com>
author:               berberman
stability:            alpha
homepage:             https://github.com/berberman/arch-web
synopsis:             Arch Linux official and AUR web interface binding
description:
    Arch Linux official and AUR web interface binding.
    See README for details.

category:             Web
abi:                  7fa0b689f0add58fb1574680295fd120
exposed:              True
exposed-modules:
    Web.ArchLinux Web.ArchLinux.API Web.ArchLinux.Types
    Web.ArchLinux.Types.Lens

hidden-modules:       Web.ArchLinux.Types.API
import-dirs:          /usr/lib/ghc-9.2.8/site-local/arch-web-0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/arch-web-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arch-web
hs-libraries:         HSarch-web-0.2-Up5GzlXDDZ6EO4r6prGGm
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    deriving-aeson-0.2.9-DnbfezSe8bWKyurzElbj3I exceptions-0.10.4
    http-client-0.7.15-15pF87z30Lb260fGpQvD7x
    http-client-tls-0.3.6.3-7PKwybeQpZP3STjfZ1Ty3Q
    http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
    lens-5.2.3-JhnKgAx9k76Jin0xTqnLw0 mtl-2.2.2
    servant-0.20.2-Ao9FJb1nrGg31HF8azeLuw
    servant-client-0.20-8D8xgQkcaQD1l8EGN94lYc
    servant-client-core-0.20.2-7zLiiUml5Y9KrgELjn5oYN text-1.2.5.0
    time-1.11.1.1

haddock-interfaces:   /usr/share/doc/haskell-arch-web/html/arch-web.haddock
haddock-html:         /usr/share/doc/haskell-arch-web/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
